.. Sage documentation master file, created by sphinx-quickstart on Thu
.. Aug 21 20:15:55 2008. You can adapt this file completely to your
.. liking, but it should at least contain the root `toctree` directive.

.. _thematic-tutorials:

Sage Thematic Tutorials
=======================

Here you will find Sage demonstrations, quick reference cards, primers, and
thematic tutorials,

.. To be reinstated once we have some of them in the Sage sources!
.. - A *demonstration* is a short document giving a broad view of the
..   available features on a given theme; it is typically presented
..   during a talk, and lasts a couple minutes.

- A *quickref* (or quick reference card) is a one page document with
  the essential examples, and pointers to the main entry points.

- A *primer* is a document meant for a user to get started by himself
  on a theme in a matter of minutes.

- A *tutorial* is more in-depth and could take as much as an hour or
  more to get through.

This documentation is licensed under a `Creative Commons Attribution-Share Alike
3.0 License <http://creativecommons.org/licenses/by-sa/3.0/>`_.

Introduction to Sage
--------------------

* `Introductory Sage Tutorial (PREP) <../prep/Intro-Tutorial.html>`_
* `Sage's main tutorial <../tutorial/index.html>`_

.. _programming_design:

Introduction to Python
----------------------

* `Tutorial: Sage Introductory Programming (PREP) <../prep/Programming.html>`_
* :ref:`tutorial-programming-python`
* :ref:`tutorial-comprehensions`
* :ref:`tutorial-objects-and-classes`
* :ref:`functional_programming`

Calculus and Plotting
---------------------

* `Tutorial: Symbolics and Plotting (PREP) <../prep/Symbolics-and-Basic-Plotting.html>`_
* `Tutorial: Calculus (PREP) <../prep/Calculus.html>`_
* `Tutorial: Advanced-2D Plotting (PREP) <../prep/Advanced-2DPlotting.html>`_
* :ref:`vector_calculus`

Algebra
-------

* :ref:`group_theory`
* :ref:`lie`
* :ref:`sage.modules.tutorial_free_modules`
* :ref:`steenrod_algebra_modules`

Number Theory
-------------

* :ref:`numtheory_rsa`
* :ref:`sage.rings.padics.tutorial`
* :ref:`explicit_methods_in_number_theory`

.. Monoids, Groups, representation Theory
.. --------------------------------------

Geometry
--------

* :ref:`geometry`

Combinatorics
-------------

* :ref:`sage.combinat.tutorial`
* :ref:`coding_theory`
* :ref:`structures_in_coding_theory`

Algebraic Combinatorics
-----------------------

* :ref:`algebraic_combinatorics`
* :class:`Tutorial: Symmetric Functions <SymmetricFunctions>`
* :ref:`lie`
* :ref:`sage.combinat.root_system.plot`
* :ref:`abelian_sandpile_model`

Parents/Elements, Categories and Algebraic Structures
-----------------------------------------------------

* :ref:`coercion_and_categories`
* :ref:`sage.categories.primer`
* :ref:`sage.categories.tutorial`
* :ref:`tutorial-implementing-algebraic-structures`

Numerical Computations
----------------------

* :ref:`numerical_computing`
* :ref:`linear_programming`

Advanced Programming
--------------------

* :ref:`cython_interface`
* :ref:`profiling`

.. Words
.. -----

.. Dynamics
.. --------

Documentation
=============

* :ref:`sws2rst`

.. Sage development
.. ----------------

.. A hidden toctree. Sphinx wants everything to be in some toctree.

.. toctree::
   :hidden:
   :maxdepth: 1

   toctree
